@@ -19,6 +19,7 @@ from pykotor.common.stream import BinaryReader
 from pykotor.extract.file import ResourceIdentifier
 from pykotor.extract.installation import Installation, SearchLocation
 from pykotor.resource.formats.lyt import LYT
+from pykotor.resource.formats.tpc import TPC
 from pykotor.resource.formats.twoda import read_2da
 from pykotor.resource.generics.git import GIT, GITPlaceable, GITCreature, GITDoor, GITTrigger, GITEncounter, \
     GITWaypoint, GITSound, GITStore, GITCamera, GITInstance
@@ -387,11 +388,15 @@ class Scene:
 
     def texture(self, name: str) -> Texture:
         if name not in self.textures:
-            # Check the textures linked to the module first
-            tpc = self.module.texture(name).resource() if self.module.texture(name) is not None else None
-            # Otherwise just search through all relevant game files
-            tpc = self.installation.texture(name, [SearchLocation.OVERRIDE, SearchLocation.TEXTURES_TPA,
-                                                   SearchLocation.CHITIN]) if tpc is None else tpc
+            try:
+                # Check the textures linked to the module first
+                tpc = self.module.texture(name).resource() if self.module.texture(name) is not None else None
+                # Otherwise just search through all relevant game files
+                tpc = self.installation.texture(name, [SearchLocation.OVERRIDE, SearchLocation.TEXTURES_TPA,
+                                                       SearchLocation.CHITIN]) if tpc is None else tpc
+            except (ValueError, IOError):
+                # If an error occurs during the loading process, just use a blank image.
+                tpc = TPC()
 
             self.textures[name] = Texture.from_tpc(tpc) if tpc is not None else Texture.from_color(255, 0, 255)
         return self.textures[name]
@@ -559,15 +564,15 @@ class Camera:
             self.pitch = 0
 
     def forward(self, ignoreZ: bool = True) -> vec3:
-        eye_x = math.sin(self.yaw) * math.sin(self.pitch)
-        eye_y = math.cos(self.yaw) * math.sin(self.pitch)
-        eye_z = 0 if ignoreZ else math.sin(self.pitch)
-        return glm.normalize(vec3(-eye_x, eye_y, eye_z))
+        eye_x = -math.cos(self.yaw) * math.cos(self.pitch - math.pi/2)
+        eye_y = math.sin(self.yaw) * math.cos(self.pitch - math.pi/2)
+        eye_z = 0 if ignoreZ else math.sin(self.pitch - math.pi/2)
+        return -glm.normalize(vec3(eye_y, eye_x, eye_z))
 
     def sideward(self, ignoreZ: bool = True) -> vec3:
-        eye_x = math.cos(self.yaw) * math.cos(self.pitch)
-        eye_y = math.sin(self.yaw) * math.cos(self.pitch)
-        eye_z = 0 if ignoreZ else math.sin(self.pitch)
+        eye_x = math.cos(self.yaw) * math.cos(self.pitch - math.pi/2)
+        eye_y = math.sin(self.yaw) * math.cos(self.pitch - math.pi/2)
+        eye_z = 0 if ignoreZ else math.sin(self.pitch - math.pi/2)
         return glm.normalize(-vec3(eye_x, eye_y, eye_z))
 
     def upward(self, ignoreXY: bool = True) -> vec3:
